summaryrefslogtreecommitdiffstats
path: root/lib/kross/main/scriptaction.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-02-01 15:02:43 -0600
committerTimothy Pearson <[email protected]>2013-02-01 15:02:43 -0600
commitaea627236e4de24599c3e30617cf264c3c1b7d40 (patch)
tree467e13ca5a7eb0ab292259289ecc3572f53c5eae /lib/kross/main/scriptaction.h
parent786304c6211f35ddc4cdd54b7aa7985fef4a2e70 (diff)
downloadkoffice-aea627236e4de24599c3e30617cf264c3c1b7d40.tar.gz
koffice-aea627236e4de24599c3e30617cf264c3c1b7d40.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'lib/kross/main/scriptaction.h')
-rw-r--r--lib/kross/main/scriptaction.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/kross/main/scriptaction.h b/lib/kross/main/scriptaction.h
index 3d6e890b..4d60d4dc 100644
--- a/lib/kross/main/scriptaction.h
+++ b/lib/kross/main/scriptaction.h
@@ -33,11 +33,11 @@ namespace Kross { namespace Api {
class ScriptActionPrivate;
/**
* A ScriptAction extends a KAction by providing a wrapper around
* a \a ScriptContainer to execute scripting code on activation.
*/
class ScriptAction
- : public KAction
+ : public TDEAction
, public Kross::Api::ScriptContainer
{
Q_OBJECT
@@ -206,10 +206,10 @@ namespace Kross { namespace Api {
TQMap<TQCString, ScriptAction::Ptr> m_actions;
/**
* A KActionMenu which could be used to display the
* content of this \a ScriptActionCollection instance.
*/
- KActionMenu* m_actionmenu;
+ TDEActionMenu* m_actionmenu;
/**
* Boolean value used to represent the modified-state. Will
@@ -234,12 +234,12 @@ namespace Kross { namespace Api {
* Constructor.
*
* \param text The text used to display some describing caption.
* \param ac The KActionCollection which should be used to as
* initial content for the KActionMenu \a m_actionmenu .
* \param name The internal name.
*/
- ScriptActionCollection(const TQString& text, KActionCollection* ac, const char* name)
- : m_actionmenu( new KActionMenu(text, ac, name) )
+ ScriptActionCollection(const TQString& text, TDEActionCollection* ac, const char* name)
+ : m_actionmenu( new TDEActionMenu(text, ac, name) )
, m_dirty(true) {}
@@ -263,9 +263,9 @@ namespace Kross { namespace Api {
TQValueList<ScriptAction::Ptr> actions() { return m_list; }
/**
- * \return the KActionMenu \a m_actionmenu .
+ * \return the TDEActionMenu \a m_actionmenu .
*/
- KActionMenu* actionMenu() { return m_actionmenu; }
+ TDEActionMenu* actionMenu() { return m_actionmenu; }
/**
* Attach a \a ScriptAction instance to this \a ScriptActionCollection .
@@ -33,11 +33,11 @@ namespace Kross { namespace Api {
class ScriptActionPrivate;
/**
- * A ScriptAction extends a KAction by providing a wrapper around
+ * A ScriptAction extends a TDEAction by providing a wrapper around
* a \a ScriptContainer to execute scripting code on activation.
*/
@@ -206,10 +206,10 @@ namespace Kross { namespace Api {
TQMap<TQCString, ScriptAction::Ptr> m_actions;
/**
- * A KActionMenu which could be used to display the
+ * A TDEActionMenu which could be used to display the
* content of this \a ScriptActionCollection instance.
*/
@@ -234,12 +234,12 @@ namespace Kross { namespace Api {
*
* \param text The text used to display some describing caption.
- * \param ac The KActionCollection which should be used to as
- * initial content for the KActionMenu \a m_actionmenu .
+ * \param ac The TDEActionCollection which should be used to as
+ * initial content for the TDEActionMenu \a m_actionmenu .
* \param name The internal name.
*/